@@ -2,6 +2,8 @@
 #' 
 #' @name i2e
 #' @param x A Leontief decomposed Inter-Country Input Output table as created by decompr
+#' @param by variable to subset by
+#' @param subset value(s) of the subset variable to select
 #' @export
 #' @import decompr
 #' @examples 
@@ -12,17 +14,17 @@
 #' data(leather)
 #' 
 #' # create a leontief decomposed data set
-#' l <- decomp(inter,
-#'             final,
-#'             countries,
-#'             industries,
-#'             out)
+#' l <- decomp(x = inter,
+#'             y = final,
+#'             k = countries,
+#'             i = industries,
+#'             o = out)
 #'  
 #'  # apply the Import to Exports analysis
 #'  i2e( l )
 
 
-i2e <- function( x ) {
+i2e <- function( x, by=NULL, subset=NULL ) {
   
   # read attributes
   k      <- attr(x, "k")
@@ -31,17 +33,26 @@ i2e <- function( x ) {
   G <- length(k)
   N <- length(i)
   
+  # select observations
+  if (!is.null(by)) {
+    position <- which(names(x) == by)
+    x[which(x[position] != subset),]$FVAX <- 0
+  }
+  
   # transform back to 2dim x 2dim matrix
   x <- matrix(x[,5], nrow=G*N, byrow=TRUE)
   
   # remove exports to self
-  f <- colSums ( x - diagonals::fatdiag(diagonals::fatdiag(x, steps=G), steps=G ) )
+  f <- x - diagonals::fatdiag(diagonals::fatdiag(x, steps=G), steps=G )
+  
+  # sum over columns
+  f <- colSums( f )
 
-  # divide by own exports
-  for (j in 1:N) {
-    s <- seq( ((j-1)*N + 1), j*N )
-    f[s] <- f[s] / sum(colSums(x[,s]))
-  }
+  # # divide by own exports
+  # for (j in 1:N) {
+  #   s <- seq( ((j-1)*N + 1), j*N )
+  #   f[s] <- f[s] / sum(colSums(x[,s]))
+  # }
   
   f <- as.data.frame(f)
   f <- cbind(rep(k, each = N),
