@@ -11,11 +11,11 @@ data(leather)
 context("leontief long format")
 
 # create a leontief long decomposed data set
-l <- decomp(inter,
-            final,
-            countries,
-            industries,
-            out)
+l <- decomp(x = inter,
+            y = final,
+            k = countries,
+            i = industries,
+            o = out)
 
 # apply the nrca to leontief
 lnrca <- nrca( l )
@@ -32,11 +32,11 @@ test_that("output values match", {
 # define short context
 context("leontief matrix format")
 
-do <- load_tables_vectors(inter,
-                          final,
-                          countries,
-                          industries,
-                          out)
+do <- load_tables_vectors(x = inter,
+                          y = final,
+                          k = countries,
+                          i = industries,
+                          o = out)
 
 lm <- leontief(do, long=FALSE)
 
